@@ -55,6 +55,10 @@
 		ROOM_TYPE_PUBLIC: 3,
 		ROOM_TYPE_CHANGELOG: 4,
 
+		/* Must stay in sync with values in "lib/Webinary.php". */
+		LOBBY_NONE: 0,
+		LOBBY_NON_MODERATORS: 1,
+
 		/** @property {OCA.SpreedMe.Models.Room} activeRoom  */
 		activeRoom: null,
 
@@ -231,6 +235,19 @@
 				$('div[contenteditable=true]:focus').length === 0 &&
 				!event.ctrlKey) {
 
+				// Shortcuts are not available in the starting page (before
+				// joining a room).
+				if (!this.activeRoom) {
+					return;
+				}
+
+				// When not in a call, only the f-shortcut is visible and can be used
+				var flags = this.activeRoom.get('participantFlags') || 0;
+				var inCall = (flags & OCA.SpreedMe.app.FLAG_IN_CALL) !== 0;
+				if (!inCall && key !== 70) {
+					return;
+				}
+
 				// Actual shortcut handling
 				switch (key) {
 					case 86: // 'v'
@@ -320,7 +337,7 @@
 		 * @param {string} token
 		 */
 		_setRoomActive: function(token) {
-			if (OC.getCurrentUser().uid) {
+			if (OCA.Talk.getCurrentUser().uid) {
 				this._rooms.forEach(function(room) {
 					room.set('active', room.get('token') === token);
 				});
@@ -341,10 +358,14 @@
 			var self = this;
 			this.signaling.syncRooms()
 				.then(function() {
-					self.stopListening(self.activeRoom, 'change:displayName');
-					self.stopListening(self.activeRoom, 'change:participantFlags');
+					self.stopListening(self.activeRoom, 'change:displayName', self._updatePageTitleOnDisplayNameChange);
+					self.stopListening(self.activeRoom, 'change:participantFlags', self.updateContentsLayout);
+					self.stopListening(self.activeRoom, 'change:participantType', self.updateContentsLayout);
+					self.stopListening(self.activeRoom, 'change:participantType', self._updateSidebar);
+					self.stopListening(self.activeRoom, 'change:lobbyState', self.updateContentsLayout);
+					self.stopListening(self.activeRoom, 'change:lobbyState', self._updateSidebar);
 
-					if (OC.getCurrentUser().uid) {
+					if (OCA.Talk.getCurrentUser().uid) {
 						roomChannel.trigger('active', token);
 
 						self._rooms.forEach(function(room) {
@@ -357,52 +378,83 @@
 					self._emptyContentView.setActiveRoom(self.activeRoom);
 
 					self.setPageTitle(self.activeRoom.get('displayName'));
-					self.listenTo(self.activeRoom, 'change:displayName', function(model, value) {
-						self.setPageTitle(value);
-					});
+					self.listenTo(self.activeRoom, 'change:displayName', self._updatePageTitleOnDisplayNameChange);
 
 					self.updateContentsLayout();
 					self.listenTo(self.activeRoom, 'change:participantFlags', self.updateContentsLayout);
+					self.listenTo(self.activeRoom, 'change:participantType', self.updateContentsLayout);
+					self.listenTo(self.activeRoom, 'change:participantType', self._updateSidebar);
+					self.listenTo(self.activeRoom, 'change:lobbyState', self.updateContentsLayout);
+					self.listenTo(self.activeRoom, 'change:lobbyState', self._updateSidebar);
 
 					self.updateSidebarWithActiveRoom();
 				});
 		},
+		_updatePageTitleOnDisplayNameChange: function(model, value) {
+			this.setPageTitle(value);
+		},
 		updateContentsLayout: function() {
 			if (!this.activeRoom) {
 				// This should never happen, but just in case
 				return;
 			}
 
+			if (this.activeRoom.isCurrentParticipantInLobby()) {
+				this._showEmptyContentViewInMainView();
+
+				return;
+			}
+
 			var flags = this.activeRoom.get('participantFlags') || 0;
 			var inCall = flags & OCA.SpreedMe.app.FLAG_IN_CALL !== 0;
-			if (inCall && this._chatViewInMainView === true) {
-				this._chatView.$el.detach();
-				this._sidebarView.addTab('chat', { label: t('spreed', 'Chat'), icon: 'icon-comment', priority: 100 }, this._chatView);
-				this._sidebarView.selectTab('chat');
-				this._chatView.reloadMessageList();
-				this._chatView.setTooltipContainer(this._chatView.$el);
-				this._chatViewInMainView = false;
-			} else if (!inCall && !this._chatViewInMainView) {
+			if (inCall) {
+				this._showCallViewInMainView();
+			} else if (!inCall) {
+				this._showChatViewInMainView();
+			}
+		},
+		_showChatViewInMainView: function() {
+			if (!this._chatViewInMainView) {
 				this._sidebarView.removeTab('chat');
 				this._chatView.$el.prependTo('#app-content-wrapper');
-				this._chatView.reloadMessageList();
+				this._chatView.handleSizeChanged();
 				this._chatView.setTooltipContainer($('#app'));
 				this._chatView.focusChatInput();
 				this._chatViewInMainView = true;
 			}
 
-			if (inCall) {
-				$('#videos').show();
-				$('#screens').show();
-				$('#emptycontent').hide();
-			} else {
-				$('#videos').hide();
-				$('#screens').hide();
-				$('#emptycontent').show();
-			}
+			$('#videos').hide();
+			$('#screens').hide();
+			$('#emptycontent').show();
 		},
-		updateSidebarWithActiveRoom: function() {
-			this._sidebarView.enable();
+		_showCallViewInMainView: function() {
+			if (this._chatViewInMainView) {
+				this._chatView.$el.detach();
+				this._sidebarView.addTab('chat', { label: t('spreed', 'Chat'), icon: 'icon-comment', priority: 100 }, this._chatView);
+				this._sidebarView.selectTab('chat');
+				this._chatView.handleSizeChanged();
+				this._chatView.setTooltipContainer(this._chatView.$el);
+				this._chatViewInMainView = false;
+			}
+
+			$('#videos').show();
+			$('#screens').show();
+			$('#emptycontent').hide();
+		},
+		_showEmptyContentViewInMainView: function() {
+			this._chatView.$el.detach();
+			this._chatViewInMainView = false;
+
+			$('#videos').hide();
+			$('#screens').hide();
+			$('#emptycontent').show();
+		},
+		_updateSidebar: function() {
+			if (!this.activeRoom.isCurrentParticipantInLobby()) {
+				this._sidebarView.enable();
+			} else {
+				this._sidebarView.disable();
+			}
 
 			// The sidebar has a width of 27% of the window width and a minimum
 			// width of 300px. Therefore, when the window is 1111px wide or
@@ -416,6 +468,13 @@
 				this._sidebarView.open();
 			}
 
+			if (this.activeRoom.isCurrentParticipantInLobby()) {
+				this._messageCollection.stopReceivingMessages();
+			} else {
+				this._messageCollection.receiveMessages();
+			}
+		},
+		updateSidebarWithActiveRoom: function() {
 			var callInfoView = new OCA.SpreedMe.Views.CallInfoView({
 				model: this.activeRoom,
 				guestNameModel: this._localStorageModel
@@ -424,7 +483,8 @@
 
 			this._chatView.setRoom(this.activeRoom);
 			this._messageCollection.setRoomToken(this.activeRoom.get('token'));
-			this._messageCollection.receiveMessages();
+
+			this._updateSidebar();
 		},
 		setPageTitle: function(title){
 			if (title) {
@@ -444,7 +504,7 @@
 			this._sidebarView = new OCA.SpreedMe.Views.SidebarView();
 			$('#content').append(this._sidebarView.$el);
 
-			if (OC.getCurrentUser().uid) {
+			if (OCA.Talk.getCurrentUser().uid) {
 				this._rooms = new OCA.SpreedMe.Models.RoomCollection();
 				this.listenTo(roomChannel, 'active', this._setRoomActive);
 			} else {
@@ -483,6 +543,11 @@
 				}
 
 				this._chatView.restoreScrollPosition();
+
+				// When the chat is attached again the message list needs to be
+				// reloaded to add the messages that could have been received
+				// while detached.
+				this._chatView.reloadMessageList();
 			}.bind(this));
 			this._chatView.listenTo(this._sidebarView, 'close', function() {
 				if (this._sidebarView.getCurrentTabId() !== 'chat') {
@@ -518,55 +583,50 @@
 			}.bind(this));
 
 			// Opening or closing the sidebar changes the width of the main
-			// view, so if the chat view is in the main view it needs to be
-			// reloaded.
-			var reloadMessageListOnSidebarVisibilityChange = function() {
+			// view, so if the chat view is in the main view it needs to handle
+			// a size change.
+			var handleSizeChangedOnSidebarVisibilityChange = function() {
 				if (!this._chatViewInMainView) {
 					return;
 				}
 
-				this._chatView.reloadMessageList();
+				this._chatView.handleSizeChanged();
 			}.bind(this);
-			this._chatView.listenTo(this._sidebarView, 'opened', reloadMessageListOnSidebarVisibilityChange);
-			this._chatView.listenTo(this._sidebarView, 'closed', reloadMessageListOnSidebarVisibilityChange);
+			this._chatView.listenTo(this._sidebarView, 'opened', handleSizeChangedOnSidebarVisibilityChange);
+			this._chatView.listenTo(this._sidebarView, 'closed', handleSizeChangedOnSidebarVisibilityChange);
 
 			// Resizing the window can change the size of the chat view, both
 			// when it is in the main view and in the sidebar, so the chat view
-			// needs to be reloaded. The initial reload is not very heavy, so
-			// the handler is not debounced for a snappier feel and to reduce
-			// flickering.
+			// needs to handle a size change. The initial reload is not very
+			// heavy, so the window resize handler is not debounced for a
+			// snappier feel and to reduce flickering.
 			// However, resizing the window below certain width causes the
 			// navigation bar to be hidden; an explicit handling is needed in
 			// this case because the app navigation (or, more specifically, its
 			// Snap object) adds a transition to the app content, so the reload
 			// needs to be delayed to give the transition time to end and thus
 			// give the app content time to get its final size.
-			var reloadMessageListOnWindowResize = function() {
+			var handleSizeChangedOnWindowResize = function() {
 				var chatView = this._chatView;
 
 				if ($(window).width() >= 768 || !this._chatViewInMainView) {
-					chatView.reloadMessageList();
+					chatView.handleSizeChanged();
 
 					return;
 				}
 
 				setTimeout(function() {
-					chatView.reloadMessageList();
+					chatView.handleSizeChanged();
 				}, 300);
 			}.bind(this);
-			$(window).resize(reloadMessageListOnWindowResize);
+			$(window).resize(handleSizeChangedOnWindowResize);
 
 			this._messageCollection.listenTo(roomChannel, 'leaveCurrentRoom', function() {
 				this.stopReceivingMessages();
 			});
 
 			this.listenTo(roomChannel, 'leaveCurrentRoom', function() {
-				this._chatView.$el.detach();
-				this._chatViewInMainView = false;
-
-				$('#videos').hide();
-				$('#screens').hide();
-				$('#emptycontent').show();
+				this._showEmptyContentViewInMainView();
 			});
 
 			this.listenTo(roomChannel, 'joinRoom', function(token) {
@@ -605,6 +665,8 @@
 
 			this._mediaControlsView = this._localVideoView._mediaControlsView;
 
+			this._speakingWhileMutedWarner = new OCA.Talk.Views.SpeakingWhileMutedWarner(this._mediaControlsView);
+
 			$(document).on('click', this.onDocumentClick);
 			OC.Util.History.addOnPopStateHandler(_.bind(this._onPopState, this));
 		},
@@ -613,7 +675,13 @@
 			this.connection = new OCA.Talk.Connection(this);
 			this.token = $('#app').attr('data-token');
 
-			this.signaling.on('joinRoom', function(/* token */) {
+			this.signaling.on('joinRoom', function(token) {
+				if (this.token !== token) {
+					return;
+				}
+
+				this.syncAndSetActiveRoom(token);
+
 				this.inRoom = true;
 				if (this.pendingNickChange) {
 					this.setGuestName(this.pendingNickChange);
@@ -662,7 +730,7 @@
 				this.signaling.disconnect();
 			}.bind(this));
 
-			if (OC.getCurrentUser().uid) {
+			if (OCA.Talk.getCurrentUser().uid) {
 				this._showRoomList();
 				this.signaling.setRoomCollection(this._rooms)
 					.then(function(data) {
@@ -707,6 +775,7 @@
 				OCA.SpreedMe.initWebRTC(this);
 				this._mediaControlsView.setWebRtc(OCA.SpreedMe.webrtc);
 				this._mediaControlsView.setSharedScreens(OCA.SpreedMe.sharedScreens);
+				this._speakingWhileMutedWarner.setWebRtc(OCA.SpreedMe.webrtc);
 			}
 
 			if (!OCA.SpreedMe.webrtc.capabilities.supportRTCPeerConnection) {
@@ -870,13 +939,13 @@
 				var $input = $(e.trigger);
 				$input.tooltip('hide')
 					.attr('data-original-title', t('core', 'Copied!'))
-					.tooltip('fixTitle')
+					.tooltip('_fixTitle')
 					.tooltip({placement: 'bottom', trigger: 'manual'})
 					.tooltip('show');
 				_.delay(function() {
 					$input.tooltip('hide')
 						.attr('data-original-title', t('core', 'Copy'))
-						.tooltip('fixTitle');
+						.tooltip('_fixTitle');
 				}, 3000);
 			});
 			clipboard.on('error', function (e) {
@@ -892,13 +961,13 @@
 
 				$input.tooltip('hide')
 					.attr('data-original-title', actionMsg)
-					.tooltip('fixTitle')
+					.tooltip('_fixTitle')
 					.tooltip({placement: 'bottom', trigger: 'manual'})
 					.tooltip('show');
 				_.delay(function () {
 					$input.tooltip('hide')
 						.attr('data-original-title', t('spreed', 'Copy'))
-						.tooltip('fixTitle');
+						.tooltip('_fixTitle');
 				}, 3000);
 			});
 		}
