@@ -47,25 +47,20 @@
 			var canModerate = this._canModerate();
 			var canFullModerate = this._canFullModerate();
 			var isPublic = this.model.get('type') === OCA.SpreedMe.app.ROOM_TYPE_PUBLIC;
+			var isLobbyActive = this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NON_MODERATORS;
 			return $.extend(this.model.toJSON(), {
 				isRoomForFile: this.model.get('objectType') === 'file',
 				fileLink: OC.generateUrl('/f/{fileId}', { fileId: this.model.get('objectId') }),
 				fileLinkTitle: t('spreed', 'Go to file'),
 				showRoomModerationMenu: canModerate && (canFullModerate || isPublic),
 				canFullModerate: canFullModerate,
+				linkLabel: t('spreed', 'Guests'),
 				linkCheckboxLabel: t('spreed', 'Share link'),
 				copyLinkLabel: t('spreed', 'Copy link'),
-				enableForLabel: t('spreed', 'Enable for'),
-				allParticipantsLabel: t('spreed', 'All participants'),
-				moderatorsOnlyLabel: t('spreed', 'Moderators only'),
-				allParticipantsValue: OCA.SpreedMe.app.LOBBY_NONE,
-				moderatorsOnlyValue: OCA.SpreedMe.app.LOBBY_NON_MODERATORS,
-				lobbyStateAllParticipants: this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NONE,
-				lobbyStateModeratorsOnly: this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NON_MODERATORS,
-				lobbyTimerPlaceholder: t('spreed', 'Start time (optional)'),
-				// PHP timestamp is second-based; JavaScript timestamp is
-				// millisecond based.
-				lobbyTimerValue: this.model.get('lobbyTimer')? OC.Util.formatDate(this.model.get('lobbyTimer') * 1000, 'YYYY-MM-DD HH:mm:ss') : '',
+				webinarLabel: t('spreed', 'Webinar'),
+				lobbyCheckboxLabel: t('spreed', 'Enable lobby'),
+				lobbyCheckboxDetail: t('spreed', 'Only moderators can enter the conversation when the lobby is enabled'),
+				isLobbyActive: isLobbyActive,
 				isPublic: isPublic,
 				passwordInputPlaceholder: this.model.get('hasPassword')? t('spreed', 'Change password'): t('spreed', 'Set password'),
 				isDeletable: canModerate && (Object.keys(this.model.get('participants')).length > 2 || this.model.get('numGuests') > 0)
@@ -89,13 +84,11 @@
 			'roomModerationButton': '.room-moderation-button .button',
 			'roomModerationMenu': '.room-moderation-button .menu',
 
-			'allParticipantsRadio': '.all-participants-radio',
-			'moderatorsOnlyRadio': '.moderators-only-radio',
-			'allParticipantsLabel': '.all-participants-label',
-			'moderatorsOnlyLabel': '.moderators-only-label',
-
+			'lobbyCheckbox': '.lobby-checkbox',
+			'lobbyCheckboxLabel': '.lobby-checkbox-label',
+			'lobbyTimerOption': '.lobby-timer-option',
 			'lobbyTimerForm': '.lobby-timer-form',
-			'lobbyTimerInput': '.lobby-timer-input',
+			'lobbyTimerPicker': '.lobby-timer-picker',
 			'lobbyTimerConfirm': '.lobby-timer-confirm',
 			'lobbyTimerLoading': '.lobby-timer-loading',
 		},
@@ -103,6 +96,7 @@
 		regions: {
 			'roomName': '@ui.roomName',
 			'callButton': '@ui.callButton',
+			'lobbyTimerPicker': '@ui.lobbyTimerPicker',
 		},
 
 		events: {
@@ -111,9 +105,7 @@
 			'click @ui.passwordConfirm': 'confirmPassword',
 			'submit @ui.passwordForm': 'confirmPassword',
 
-			'click @ui.allParticipantsRadio': 'setLobbyStateAllParticipants',
-			'click @ui.moderatorsOnlyRadio': 'setLobbyStateModeratorsOnly',
-
+			'change @ui.lobbyCheckbox': 'toggleLobbyCheckbox',
 			'click @ui.lobbyTimerConfirm': 'confirmLobbyTimer',
 			'submit @ui.lobbyTimerForm': 'confirmLobbyTimer',
 		},
@@ -126,6 +118,9 @@
 				this.render();
 			},
 			'change:lobbyTimer': function() {
+				if (this._updateLobbyTimerPickerValue) {
+					this._updateLobbyTimerPickerValue();
+				}
 				this.render();
 			},
 			'change:participantType': function() {
@@ -155,7 +150,7 @@
 				modelSaveOptions: {
 					wait: true,
 					error: function() {
-						OC.Notification.show(t('spreed', 'Error occurred while renaming the room'), {type: 'error'});
+						OC.Notification.show(t('spreed', 'Error occurred while renaming the conversation'), {type: 'error'});
 					}
 				},
 
@@ -172,6 +167,31 @@
 				connection: OCA.SpreedMe.app.connection,
 			});
 
+			// The DatetimePicker is shown only in the UI for logged in users,
+			// but not in the UI for guests (even if it is a guest moderator).
+			if (OCA.Talk.getCurrentUser().uid) {
+				this._lobbyTimerPicker = new OCA.Talk.Views.VueWrapper({
+					vm: new OCA.Talk.Views.LobbyTimerPicker()
+				});
+
+				// The DatetimePicker component does not seem to provide any event
+				// to know when the popup is shown or hidden, although in most cases
+				// it corresponds with the input being focused or not.
+				this._lobbyTimerPicker._vm.$on('focus', function() {
+					this.ui.lobbyTimerOption.addClass('with-datepicker-popup');
+				}.bind(this));
+				this._lobbyTimerPicker._vm.$on('blur', function() {
+					this.ui.lobbyTimerOption.removeClass('with-datepicker-popup');
+				}.bind(this));
+
+				this._updateLobbyTimerPickerValue = function() {
+					// PHP timestamp is second-based; JavaScript timestamp is
+					// millisecond based.
+					this._lobbyTimerPicker._vm.value = this.model.get('lobbyTimer')? new Date(this.model.get('lobbyTimer') * 1000): null;
+				};
+				this._updateLobbyTimerPickerValue();
+			}
+
 			this._updateNameEditability();
 		},
 
@@ -187,6 +207,18 @@
 			// time and without that option the call would fail otherwise.
 			this.getRegion('roomName').reset({ preventDestroy: true, allowMissingEl: true });
 			this.getRegion('callButton').reset({ preventDestroy: true, allowMissingEl: true });
+			this.getRegion('lobbyTimerPicker').reset({ preventDestroy: true, allowMissingEl: true });
+
+			// Remove previous tooltips in case any of them is shown, as
+			// otherwise they will stay forever in the DOM once their parent is
+			// removed.
+			if (this._clipboardButtonTooltip) {
+				this._clipboardButtonTooltip.tooltip('dispose');
+			}
+
+			if (this._fileLinkTooltip) {
+				this._fileLinkTooltip.tooltip('dispose');
+			}
 		},
 
 		onRender: function() {
@@ -199,13 +231,16 @@
 			// template has been rendered.
 			this.showChildView('roomName', this._nameEditableTextLabel, { replaceElement: true } );
 			this.showChildView('callButton', this._callButton, { replaceElement: true } );
+			if (this._canFullModerate() && this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NON_MODERATORS) {
+				this.showChildView('lobbyTimerPicker', this._lobbyTimerPicker, { replaceElement: true } );
+			}
 
 			var roomURL = OC.generateUrl('/call/' + this.model.get('token')),
 				completeURL = window.location.protocol + '//' + window.location.host + roomURL;
 
 			this.ui.clipboardButton.attr('value', completeURL);
 			this.ui.clipboardButton.attr('data-clipboard-text', completeURL);
-			this.ui.clipboardButton.tooltip({
+			this._clipboardButtonTooltip = this.ui.clipboardButton.tooltip({
 				placement: 'bottom',
 				trigger: 'manual',
 				title: t('core', 'Link copied!')
@@ -214,7 +249,7 @@
 
 			// Set the body as the container to show the tooltip in front of the
 			// header.
-			this.ui.fileLink.tooltip({container: $('body')});
+			this._fileLinkTooltip = this.ui.fileLink.tooltip({container: $('body')});
 
 			OC.registerMenu(this.ui.roomModerationButton, this.ui.roomModerationMenu);
 		},
@@ -275,9 +310,9 @@
 					this.ui.linkCheckboxLabel.removeClass('icon-loading-small');
 
 					if (isPublic) {
-						OC.Notification.show(t('spreed', 'Error occurred while making the room public'), {type: 'error'});
+						OC.Notification.show(t('spreed', 'Error occurred while making the conversation public'), {type: 'error'});
 					} else {
-						OC.Notification.show(t('spreed', 'Error occurred while making the room private'), {type: 'error'});
+						OC.Notification.show(t('spreed', 'Error occurred while making the conversation private'), {type: 'error'});
 					}
 				}.bind(this)
 			});
@@ -317,50 +352,24 @@
 			});
 		},
 
-		setLobbyStateAllParticipants: function() {
-			if (this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NONE) {
-				return;
-			}
+		/**
+		 * Lobby
+		 */
+		toggleLobbyCheckbox: function() {
+			var isLobbyActive = this.ui.lobbyCheckbox.prop('checked');
+			var lobbyState = (isLobbyActive) ? OCA.SpreedMe.app.LOBBY_NON_MODERATORS : OCA.SpreedMe.app.LOBBY_NONE;
 
-			this.ui.allParticipantsRadio.prop('disabled', true);
-			this.ui.allParticipantsLabel.addClass('icon-loading-small');
+			this.ui.lobbyCheckbox.prop('disabled', true);
+			this.ui.lobbyCheckboxLabel.addClass('icon-loading-small');
 
-			this.model.setLobbyState(OCA.SpreedMe.app.LOBBY_NONE, {
+			this.model.setLobbyState(lobbyState, {
 				wait: true,
 				error: function() {
-					if (this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NONE) {
-						this.ui.allParticipantsRadio.prop('checked', true);
-					} else {
-						this.ui.moderatorsOnlyRadio.prop('checked', true);
-					}
-					this.ui.allParticipantsRadio.prop('disabled', false);
-					this.ui.allParticipantsLabel.removeClass('icon-loading-small');
+					this.ui.lobbyCheckbox.prop('checked', !isLobbyActive);
+					this.ui.lobbyCheckbox.prop('disabled', false);
+					this.ui.lobbyCheckboxLabel.removeClass('icon-loading-small');
 
-					OC.Notification.show(t('spreed', 'Error occurred while enabling for all participants'), {type: 'error'});
-				}.bind(this)
-			});
-		},
-
-		setLobbyStateModeratorsOnly: function() {
-			if (this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NON_MODERATORS) {
-				return;
-			}
-
-			this.ui.moderatorsOnlyRadio.prop('disabled', true);
-			this.ui.moderatorsOnlyLabel.addClass('icon-loading-small');
-
-			this.model.setLobbyState(OCA.SpreedMe.app.LOBBY_NON_MODERATORS, {
-				wait: true,
-				error: function() {
-					if (this.model.get('lobbyState') === OCA.SpreedMe.app.LOBBY_NONE) {
-						this.ui.allParticipantsRadio.prop('checked', true);
-					} else {
-						this.ui.moderatorsOnlyRadio.prop('checked', true);
-					}
-					this.ui.moderatorsOnlyRadio.prop('disabled', false);
-					this.ui.moderatorsOnlyLabel.removeClass('icon-loading-small');
-
-					OC.Notification.show(t('spreed', 'Error occurred while enabling only for moderators'), {type: 'error'});
+					OC.Notification.show(t('spreed', 'Error occurred while changing lobby state'), {type: 'error'});
 				}.bind(this)
 			});
 		},
@@ -370,11 +379,11 @@
 
 			var lobbyTimerTimestamp = 0;
 
-			var lobbyTimerInputValue = this.ui.lobbyTimerInput.val().trim();
-			if (lobbyTimerInputValue) {
+			var lobbyTimerPickerValue = this._lobbyTimerPicker._vm.value;
+			if (lobbyTimerPickerValue) {
 				// PHP timestamp is second-based; JavaScript timestamp is
 				// millisecond based.
-				lobbyTimerTimestamp = Date.parse(lobbyTimerInputValue) / 1000;
+				lobbyTimerTimestamp = lobbyTimerPickerValue.getTime() / 1000;
 			}
 
 			if (isNaN(lobbyTimerTimestamp)) {
@@ -383,12 +392,12 @@
 				return;
 			}
 
-			this.ui.lobbyTimerInput.prop('disabled', true);
+			this._lobbyTimerPicker._vm.disabled = true;
 			this.ui.lobbyTimerConfirm.addClass('hidden');
 			this.ui.lobbyTimerLoading.removeClass('hidden');
 
 			var restoreState = function() {
-				this.ui.lobbyTimerInput.prop('disabled', false);
+				this._lobbyTimerPicker._vm.disabled = false;
 				this.ui.lobbyTimerConfirm.removeClass('hidden');
 				this.ui.lobbyTimerLoading.addClass('hidden');
 			}.bind(this);
