@@ -228,6 +228,10 @@ var spreedPeerConnectionTable = [];
 			OCA.SpreedMe.videos.remove(sessionId);
 			delete spreedMappingTable[sessionId];
 			delete guestNamesTable[sessionId];
+			if (delayedCreatePeer[sessionId]) {
+				clearTimeout(delayedCreatePeer[sessionId]);
+				delete delayedCreatePeer[sessionId];
+			}
 		});
 
 		previousUsersInRoom = previousUsersInRoom.diff(disconnectedSessionIds);
@@ -349,6 +353,12 @@ var spreedPeerConnectionTable = [];
 				delete delayedCreatePeer[message.from];
 			}
 
+			if (!selfInCall) {
+				console.log('Offer received when not in the call, ignore');
+
+				message.type = 'offer-to-ignore';
+			}
+
 			// MCU screen offers do not include the "broadcaster" property,
 			// which is expected by SimpleWebRTC in screen offers from a remote
 			// peer, so it needs to be explicitly added.
@@ -371,7 +381,7 @@ var spreedPeerConnectionTable = [];
 			detectSpeakingEvents: true,
 			connection: signaling,
 			enableDataChannels: true,
-			nick: OC.getCurrentUser().displayName
+			nick: OCA.Talk.getCurrentUser().displayName
 		});
 		if (signaling.hasFeature('mcu')) {
 			// Force "Plan-B" semantics if the MCU is used, which doesn't support
@@ -526,7 +536,7 @@ var spreedPeerConnectionTable = [];
 							} else {
 								OCA.SpreedMe.webrtc.emit('audioOn');
 							}
-							if (!OC.getCurrentUser()['uid']) {
+							if (!OCA.Talk.getCurrentUser()['uid']) {
 								var currentGuestNick = localStorage.getItem("nick");
 								sendDataChannelToAll('status', 'nickChanged', currentGuestNick);
 							}
@@ -539,37 +549,40 @@ var spreedPeerConnectionTable = [];
 						case 'disconnected':
 							console.log('Disconnected.');
 
-							if (!signaling.hasFeature("mcu")) {
-								// ICE failures will be handled in "iceFailed"
-								// below for MCU installations.
-								videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.DISCONNECTED);
+							videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.DISCONNECTED);
+
+							setTimeout(function() {
+								if (peer.pc.iceConnectionState !== 'disconnected') {
+									return;
+								}
+
+								videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.DISCONNECTED_LONG);
+
+								if (!signaling.hasFeature("mcu")) {
+									// ICE failures will be handled in "iceFailed"
+									// below for MCU installations.
 
-								setTimeout(function() {
 									// If the peer is still disconnected after 5 seconds we try ICE restart.
-									if(peer.pc.iceConnectionState === 'disconnected') {
-										videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.DISCONNECTED_LONG);
-
-										if (spreedPeerConnectionTable[peer.id] < 5) {
-											if (peer.pc.localDescription.type === 'offer' &&
-												peer.pc.signalingState === 'stable') {
-												spreedPeerConnectionTable[peer.id] ++;
-												console.log('ICE restart.');
-												peer.icerestart();
-											}
+									if (spreedPeerConnectionTable[peer.id] < 5) {
+										if (peer.pc.localDescription.type === 'offer' &&
+											peer.pc.signalingState === 'stable') {
+											spreedPeerConnectionTable[peer.id] ++;
+											console.log('ICE restart.');
+											peer.icerestart();
 										}
 									}
-								}, 5000);
-							}
+								}
+							}, 5000);
 							break;
 						case 'failed':
 							console.log('Connection failed.');
 
+							videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.FAILED);
+
 							if (!signaling.hasFeature("mcu")) {
 								// ICE failures will be handled in "iceFailed"
 								// below for MCU installations.
 								if (spreedPeerConnectionTable[peer.id] < 5) {
-									videoView.setConnectionStatus(OCA.Talk.Views.VideoView.ConnectionStatus.FAILED);
-
 									if (peer.pc.localDescription.type === 'offer' &&
 										peer.pc.signalingState === 'stable') {
 										spreedPeerConnectionTable[peer.id] ++;
@@ -611,7 +624,7 @@ var spreedPeerConnectionTable = [];
 				OCA.SpreedMe.videos.stopSendingNick(peer);
 				peer.nickInterval = setInterval(function() {
 					var payload;
-					var user = OC.getCurrentUser();
+					var user = OCA.Talk.getCurrentUser();
 					if (!user.uid) {
 						payload = localStorage.getItem("nick");
 					} else {
@@ -1112,7 +1125,7 @@ var spreedPeerConnectionTable = [];
 			}
 		});
 
-		OCA.SpreedMe.webrtc.on('videoAdded', function(video, peer) {
+		OCA.SpreedMe.webrtc.on('videoAdded', function(video, audio, peer) {
 			console.log('VIDEO ADDED', peer);
 			if (peer.type === 'screen') {
 				OCA.SpreedMe.webrtc.emit('screenAdded', video, peer);
@@ -1132,6 +1145,7 @@ var spreedPeerConnectionTable = [];
 				videoView.setParticipant(userId, participantName);
 
 				videoView.setVideoElement(video);
+				videoView.setAudioElement(audio);
 			}
 
 			var otherSpeakerPromoted = false;
