@@ -1,134 +1,6 @@
 OC.L10N.register(
     "spreed",
     {
-    "Enter name for a new conversation" : "相手の名前を入力してください",
-    "{name} (public)" : "{name}(パブリック)",
-    "New conversation …" : "新規チャット",
-    "Participants" : "参加者",
-    "Projects" : "プロジェクト",
-    "Chat" : "チャット",
-    "Talk" : "通話",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "外部のシグナリングサーバーを使用しない4人以上の参加者による呼び出しでは、接続の問題が発生し、参加している端末の負荷が高くなる可能性があります。",
-    "Exit fullscreen (f)" : "全画面終了 (f)",
-    "Fullscreen (f)" : "全画面 (f)",
-    "Copy" : "コピー",
-    "Copied!" : "コピーしました",
-    "Not supported!" : "未対応",
-    "Press ⌘-C to copy." : "⌘-C でコピーします。",
-    "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
-    "Error while getting the room ID" : "ルームIDの取得中にエラーが発生しました",
-    "Start a conversation" : "会話を開始する",
-    "Share this file with others to discuss" : "このファイルを他のユーザーと共有してディスカッションする",
-    "Share" : "共有",
-    "Room name can not be empty" : "ルーム名を空にすることはできません",
-    "Request password" : "パスワードを入力",
-    "Error requesting the password." : "パスワードのリクエスト中にエラーが発生しました。",
-    "Please enter the password for this call" : "この通話のパスワードを入力してください",
-    "Password required" : "パスワードが必要です",
-    "Password" : "パスワード",
-    "Cancel" : "キャンセル",
-    "Submit" : "了解",
-    "Leave call" : "通話終了",
-    "Join call" : "通話開始",
-    "Start call" : "通話を開始",
-    "Calls are disabled in this conversation." : "この会話では通話は無効になっています。",
-    "Go to file" : "ファイルへ移動",
-    "Share link" : "リンクの共有",
-    "Copy link" : "リンクをコピー",
-    "All participants" : "すべての参加者",
-    "Moderators only" : "モデレータ専用",
-    "Start time (optional)" : "開始時間（オプション）",
-    "Change password" : "パスワード変更",
-    "Set password" : "パスワード設定",
-    "Name" : "名前",
-    "Conversation name" : "会話の名前",
-    "Rename" : "名前変更",
-    "Link copied!" : "リンクをコピーしました",
-    "Conversation with {name}" : "{name} と会話",
-    "Error occurred while setting password" : "パスワード設定中にエラーが発生しました",
-    "Invalid start time format" : "開始時間がフォーマットに沿っていません",
-    "You" : "自分",
-    "Guest" : "ゲスト",
-    "No messages yet, start the conversation!" : "まだメッセージはありません。会話を開始しましょう",
-    "New message …" : "新しいメッセージ …",
-    "Send" : "送信",
-    "You can not send messages, because the conversation is locked." : "会話がロックされているため、メッセージを送信できません。",
-    "The conversation is locked." : "会話はロックされています",
-    "[Unknown user name]" : "[不明なユーザー名]",
-    "Today" : "本日",
-    "Yesterday" : "昨日",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "The message you are trying to send is too long" : "送信しようとしているメッセージは長すぎます",
-    "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
-    "File to share" : "共有するファイル",
-    "Error while sharing" : "共有でエラーが発生しました",
-    "Edit" : "編集",
-    "Join a conversation or start a new one" : "会話に参加または開始する",
-    "Say hi to your friends and colleagues!" : "友達や同僚に挨拶しましょう！",
-    "No other people in this call" : "この通話には誰もいません",
-    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
-    "Waiting for others to join the call …" : "参加を待っています …",
-    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
-    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
-    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
-    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
-    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
-    "This conversation has ended" : "会話は終了しました",
-    "Set your name in the chat window so other participants can identify you better." : "チャットウィンドウで自分の名前を設定して、他の参加者が自分を識別しやすくします。",
-    "Mute audio" : "音声なし",
-    "Disable video" : "映像なし",
-    "Share screen" : "画面共有",
-    "Share whole screen" : "全画面共有",
-    "Share a single window" : "ウィンドウを共有",
-    "Show your screen" : "自分の画面を表示",
-    "Stop screensharing" : "画面共有を停止",
-    "Mute audio (m)" : "ミュート (m)",
-    "Unmute audio (m)" : "ミュート解除 (m)",
-    "No audio" : "音声なし",
-    "Disable video (v)" : "映像なし (v)",
-    "Enable video (v)" : "映像あり (v)",
-    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にする (v) -ビデオを最初に有効にすると、接続が一時的に中断されます。",
-    "No Camera" : "カメラがありません",
-    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
-    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
-    "Screensharing options" : "画面共有オプション",
-    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
-    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
-    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
-    "Enable screensharing" : "画面共有を有効にする",
-    "moderator" : "モデレータ",
-    "Demote from moderator" : "モデレータから降格",
-    "Promote to moderator" : "モデレータに昇格",
-    "Remove participant" : "参加者を削除",
-    "Error while promoting user to moderator" : "ユーザーをモデレータに昇格中にエラーが発生しました",
-    "Error while demoting moderator" : "モデレータの降格中にエラーが発生しました",
-    "Error while removing user from room" : "ルームからユーザを削除中にエラーが発生しました",
-    "Add participant …" : "参加者を追加",
-    "Favorited" : "お気に入り済",
-    "Remove from favorites" : "お気に入りから削除",
-    "Add to favorites" : "お気に入りに追加",
-    "Chat notifications" : "チャット通知",
-    "All messages" : "全てのメッセージ",
-    "@-mentions only" : "@-言及 のみ",
-    "Off" : "オフ",
-    "Leave conversation" : "会話を離れる",
-    "Delete conversation" : "会話を削除",
-    "You need to promote a new moderator before you can leave the conversation." : "会話を終了する前に、新しいモデレータを昇格する必要があります。",
-    "Your screen" : "自画面",
-    "{participantName}'s screen" : "{participantName} の画面",
-    "Guest's screen" : "ゲストの画面",
-    "Close" : "閉じる",
-    "Show screen" : "画面を表示",
-    "Enable video" : "動画を有効にする",
-    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "予想以上に時間がかかっています。メディア権限はすでに付与されていますか？（または拒否されていますか？）付与されている場合、オーディオとビデオが破損しているのでブラウザを再起動してください。",
-    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
-    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
-    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
-    "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
-    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
     "a conversation" : "会話",
     "(Duration %s)" : "(%s 期限)",
     "You attended a call with {user1}" : "{user1} との通話に参加しました",
@@ -140,6 +12,8 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["他 %n 名"],
     "{actor} invited you to {call}" : "{actor} から {call} に招待されました",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "<strong>会話</strong>への招待、または<strong>着信</strong>がありました",
+    "Talk" : "通話",
+    "Guest" : "ゲスト",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Nextcloud Talkへようこそ!\nこの会話では、Nextcloud Talkで利用できる新機能について説明します。",
     "New in Talk 6" : "トークの6つの新機能",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft EdgeとSafariで音声通話とビデオ通話ができるようになりました。",
@@ -223,6 +97,7 @@ OC.L10N.register(
     "A guest mentioned you in conversation {call}" : "ゲストが会話{call}であなたのことを話しました",
     "View chat" : "チャットを見る",
     "{user} invited you to a private conversation" : "{user}があなたをプライベートな会話に招待しました",
+    "Join call" : "通話開始",
     "{user} invited you to a group conversation: {call}" : "{user}がグループ会話{call}にあなたを招待しました",
     "Answer call" : "応答",
     "{user} wants to talk with you" : "{user} からの通話要請があります",
@@ -254,6 +129,23 @@ OC.L10N.register(
     "UDP only" : "UDP のみ",
     "TCP only" : "TCP のみ",
     "Test this server" : "このサーバーをテスト",
+    "[Unknown user name]" : "[不明なユーザー名]",
+    "Copy link" : "リンクをコピー",
+    "Chat notifications" : "チャット通知",
+    "All messages" : "全てのメッセージ",
+    "@-mentions only" : "@-言及 のみ",
+    "Off" : "オフ",
+    "Leave conversation" : "会話を離れる",
+    "Delete conversation" : "会話を削除",
+    "Remove from favorites" : "お気に入りから削除",
+    "Add to favorites" : "お気に入りに追加",
+    "moderator" : "モデレータ",
+    "Demote from moderator" : "モデレータから降格",
+    "Promote to moderator" : "モデレータに昇格",
+    "Remove participant" : "参加者を削除",
+    "Share link" : "リンクの共有",
+    "Participants" : "参加者",
+    "Projects" : "プロジェクト",
     "Limit to groups" : "グループに制限する",
     "When at least one group is selected, only people of the listed groups can be part of conversations." : "最低1つグループが選択されている場合、グループにリストされたユーザーのみが会話に参加できます。",
     "Guests can still join public conversations." : "ゲストはまだ公開会話に参加できます。",
@@ -264,13 +156,13 @@ OC.L10N.register(
     "Saved!" : "保存完了！",
     "Commands" : "コマンド",
     "Beta" : "ベータ",
+    "Name" : "名前",
     "Command" : "コマンド",
     "Script" : "スクリプト",
     "Response to" : "への反応",
     "Enabled for" : "に対して有効",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "コマンドはNextcloud Talkの新しいベータ版の機能です。スクリプトをNextcloudサーバー上で実行することができます。コマンドラインインターフェイスを使用して定義できます。計算スクリプトの例は、<a {attributes}>ドキュメント ↗</a>に記載されています。",
-    "Select a conversation to add to the project" : "プロジェクトに追加する会話を選択",
-    "Select conversation" : "会話を選択",
+    "Moderators only" : "モデレータ専用",
     "Signaling servers" : "シグナリングサーバー",
     "Saved" : "保存しました",
     "Add a new server" : "新しいサーバーの追加",
@@ -282,8 +174,15 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
     "TURN servers" : "TURNサーバー",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは、ファイアウォール内の参加者からのトラフィックをプロキシするために使用されます。",
+    "Select a conversation to add to the project" : "プロジェクトに追加する会話を選択",
+    "Select conversation" : "会話を選択",
+    "Join a conversation or start a new one" : "会話に参加または開始する",
+    "Say hi to your friends and colleagues!" : "友達や同僚に挨拶しましょう！",
+    "Link to a conversation" : "会話へのリンク",
     "This conversation is password-protected" : "この会話はパスワードで保護されています",
     "The password is wrong. Try again." : "パスワードが違います。再入力してください",
+    "Password" : "パスワード",
+    "Fullscreen (f)" : "全画面 (f)",
     "Specify commands the users can use in chats" : "ユーザーがチャットで使用できるコマンドを指定します",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "大規模に使用する場合は、オプションで外部のシグナリングサーバーを設定できます。内部のシグナリングサーバーを利用するには、空欄のままにしてください。",
     "TURN server" : "TURNサーバー",
@@ -292,7 +191,6 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "いつでも、どこでも、どのデバイスでも会話に参加できます。",
     "Android app" : "Android アプリ",
     "iOS app" : "iOS アプリ",
-    "Link to a conversation" : "会話へのリンク",
     "Signaling server URL" : "シグナリングサーバーURL",
     "Delete server" : "サーバーを削除",
     "Add new server" : "新しいサーバーを追加",
@@ -301,9 +199,99 @@ OC.L10N.register(
     "Test server" : "テストサーバー",
     "New public conversation" : "新規公開会話",
     "New group conversation" : "新規会議",
+    "{name} (public)" : "{name}(パブリック)",
+    "New conversation …" : "新規チャット",
+    "Chat" : "チャット",
+    "Exit fullscreen (f)" : "全画面終了 (f)",
+    "Set your name in the chat window so other participants can identify you better." : "チャットウィンドウで自分の名前を設定して、他の参加者が自分を識別しやすくします。",
+    "Copy" : "コピー",
+    "Copied!" : "コピーしました",
+    "Not supported!" : "未対応",
+    "Press ⌘-C to copy." : "⌘-C でコピーします。",
+    "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
+    "Error while getting the room ID" : "ルームIDの取得中にエラーが発生しました",
+    "Start a conversation" : "会話を開始する",
+    "Share this file with others to discuss" : "このファイルを他のユーザーと共有してディスカッションする",
+    "Share" : "共有",
+    "Request password" : "パスワードを入力",
+    "Error requesting the password." : "パスワードのリクエスト中にエラーが発生しました。",
+    "Please enter the password for this call" : "この通話のパスワードを入力してください",
+    "Password required" : "パスワードが必要です",
+    "Cancel" : "キャンセル",
+    "Submit" : "了解",
+    "Leave call" : "通話終了",
+    "Start call" : "通話を開始",
+    "Change password" : "パスワード変更",
+    "Set password" : "パスワード設定",
+    "Go to file" : "ファイルへ移動",
+    "Conversation name" : "会話の名前",
+    "Rename" : "名前変更",
+    "Conversation with {name}" : "{name} と会話",
+    "Error occurred while setting password" : "パスワード設定中にエラーが発生しました",
+    "Link copied!" : "リンクをコピーしました",
+    "You" : "自分",
+    "No messages yet, start the conversation!" : "まだメッセージはありません。会話を開始しましょう",
+    "New message …" : "新しいメッセージ …",
+    "Send" : "送信",
+    "Today" : "本日",
+    "Yesterday" : "昨日",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "The message you are trying to send is too long" : "送信しようとしているメッセージは長すぎます",
+    "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
+    "File to share" : "共有するファイル",
+    "Error while sharing" : "共有でエラーが発生しました",
+    "Edit" : "編集",
+    "No other people in this call" : "この通話には誰もいません",
+    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
+    "Waiting for others to join the call …" : "参加を待っています …",
+    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
+    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
+    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
+    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
+    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
+    "This conversation has ended" : "会話は終了しました",
+    "Mute audio" : "音声なし",
+    "Disable video" : "映像なし",
+    "Share screen" : "画面共有",
+    "Share whole screen" : "全画面共有",
+    "Share a single window" : "ウィンドウを共有",
+    "Show your screen" : "自分の画面を表示",
+    "Stop screensharing" : "画面共有を停止",
+    "Unmute audio (m)" : "ミュート解除 (m)",
+    "Mute audio (m)" : "ミュート (m)",
+    "No audio" : "音声なし",
+    "Enable video (v)" : "映像あり (v)",
+    "Disable video (v)" : "映像なし (v)",
+    "No Camera" : "カメラがありません",
+    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
+    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
+    "Screensharing options" : "画面共有オプション",
+    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
+    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
+    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
+    "Enable screensharing" : "画面共有を有効にする",
+    "Error while promoting user to moderator" : "ユーザーをモデレータに昇格中にエラーが発生しました",
+    "Error while demoting moderator" : "モデレータの降格中にエラーが発生しました",
+    "Error while removing user from room" : "ルームからユーザを削除中にエラーが発生しました",
+    "Add participant …" : "参加者を追加",
+    "Favorited" : "お気に入り済",
     "Always notify" : "常に通知する",
     "Notify on @-mention" : "@-mentionに通知する",
     "Never notify" : "通知しない",
+    "Close" : "閉じる",
+    "Show screen" : "画面を表示",
+    "Enable video" : "動画を有効にする",
+    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
+    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
+    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
+    "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
+    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
+    "{participantName}'s screen" : "{participantName} の画面",
+    "Guest's screen" : "ゲストの画面",
+    "Your screen" : "自画面",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong>招待</strong>または、<strong>着信</strong>がありました。",
     "_%n other guest_::_%n other guests_" : ["他のゲスト %n 名"],
     ", " : "、",
@@ -325,11 +313,22 @@ OC.L10N.register(
     "Video & audio-conferencing using WebRTC" : "WebRTCを使用したビデオ、および音声会議",
     "This call is password-protected" : "この通話はパスワードで保護されています",
     "Signaling server" : "シグナリングサーバー",
+    "Enter name for a new conversation" : "相手の名前を入力してください",
+    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "外部のシグナリングサーバーを使用しない4人以上の参加者による呼び出しでは、接続の問題が発生し、参加している端末の負荷が高くなる可能性があります。",
+    "Room name can not be empty" : "ルーム名を空にすることはできません",
+    "Calls are disabled in this conversation." : "この会話では通話は無効になっています。",
+    "You can not send messages, because the conversation is locked." : "会話がロックされているため、メッセージを送信できません。",
+    "The conversation is locked." : "会話はロックされています",
+    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "ビデオを有効にする (v) -ビデオを最初に有効にすると、接続が一時的に中断されます。",
+    "You need to promote a new moderator before you can leave the conversation." : "会話を終了する前に、新しいモデレータを昇格する必要があります。",
+    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "予想以上に時間がかかっています。メディア権限はすでに付与されていますか？（または拒否されていますか？）付与されている場合、オーディオとビデオが破損しているのでブラウザを再起動してください。",
     "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft EdgeとSafariで音声通話とビデオ通話に参加できるようになりました",
     "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- 1対1の会話が持続的になり、なにかアクシデントが起こってもグループ会話に変わらないようになりました。\nまた、参加者の1人が会話を終了しても、会話は自動的に削除されません。両方の参加者が退席した場合のみ、会話はサーバーから削除されます。",
     "* You can now notify all participants by posting \"@all\" into the chat" : "* チャットに「@all」を付けることで、参加者全員に通知できるようになりました。",
     "* With the \"arrow-up\" key you can repost your last message" : "* ↑キーを押して、最後のメッセージを再投稿できます",
     "* Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "* Talkでコマンドを使用したり、「/help」をチャットメッセージとして送信したりできるようになりました。",
-    "* With projects you can create quick links between conversations, files and other items" : "* プロジェクトを使用すると、会話、ファイル、およびその他のアイテム間のクイックリンクを作成できます"
+    "* With projects you can create quick links between conversations, files and other items" : "* プロジェクトを使用すると、会話、ファイル、およびその他のアイテム間のクイックリンクを作成できます",
+    "Invalid start time format" : "開始時間がフォーマットに沿っていません",
+    "Start time (optional)" : "開始時間（オプション）"
 },
 "nplurals=1; plural=0;");
