@@ -1,57 +1,8 @@
 OC.L10N.register(
     "spreed",
     {
-    "Enter name for a new conversation" : "輸入新對話名稱",
-    "New conversation …" : "新對話",
-    "Participants" : "參與者",
-    "Projects" : "專案項目",
-    "Chat" : "聊天",
     "Talk" : "交談",
-    "Exit fullscreen (f)" : "離開全螢幕 (f)",
-    "Fullscreen (f)" : "全螢幕 (f)",
-    "Copy" : "複製",
-    "Copied!" : "已複製！",
-    "Not supported!" : "不支援！",
-    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
-    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
-    "Start a conversation" : "新對話",
-    "Share" : "分享",
-    "Room name can not be empty" : "名稱不能空白",
-    "Password required" : "請輸入密碼",
-    "Password" : "密碼",
-    "Cancel" : "取消",
-    "Submit" : "送出",
-    "Leave call" : "離開通話",
-    "Start call" : "通話",
-    "Share link" : "分享連結",
-    "Copy link" : "複製連結",
-    "Change password" : "變更密碼",
-    "Set password" : "設定密碼",
-    "Name" : "名稱",
-    "Rename" : "重新命名",
-    "Conversation with {name}" : "和 {name} 的談話",
-    "You" : "您",
     "Guest" : "訪客",
-    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
-    "New message …" : "新訊息 ...",
-    "Send" : "傳送",
-    "[Unknown user name]" : "[未知的使用者名稱]",
-    "Today" : "今天",
-    "Yesterday" : "昨天",
-    "File to share" : "要分享的檔案",
-    "Edit" : "編輯",
-    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
-    "Say hi to your friends and colleagues!" : "跟大家打招呼",
-    "Mute audio" : "靜音",
-    "Disable video" : "停用視訊",
-    "Share screen" : "分享螢幕",
-    "Mute audio (m)" : "靜音 (m)",
-    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
-    "moderator" : "主持人",
-    "Remove from favorites" : "取消我的最愛",
-    "Add to favorites" : "加到我的最愛",
-    "Leave conversation" : "離開對話",
-    "Close" : "關閉",
     "You started a call" : "您打了一通電話",
     "None" : "無",
     "User" : "使用者",
@@ -63,12 +14,61 @@ OC.L10N.register(
     "UDP and TCP" : "UDP 和 TCP",
     "UDP only" : "僅UDP",
     "TCP only" : "僅TCP",
+    "[Unknown user name]" : "[未知的使用者名稱]",
+    "Copy link" : "複製連結",
+    "Leave conversation" : "離開對話",
+    "Remove from favorites" : "取消我的最愛",
+    "Add to favorites" : "加到我的最愛",
+    "moderator" : "主持人",
+    "Share link" : "分享連結",
+    "Participants" : "參與者",
+    "Projects" : "專案項目",
+    "Name" : "名稱",
     "Saved" : "儲存",
+    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
+    "Say hi to your friends and colleagues!" : "跟大家打招呼",
+    "Password" : "密碼",
+    "Fullscreen (f)" : "全螢幕 (f)",
     "Delete server" : "刪除伺服器",
     "Add new server" : "新增伺服器",
     "New public conversation" : "新的公開對話",
     "New group conversation" : "新群組對話",
+    "New conversation …" : "新對話",
+    "Chat" : "聊天",
+    "Exit fullscreen (f)" : "離開全螢幕 (f)",
+    "Copy" : "複製",
+    "Copied!" : "已複製！",
+    "Not supported!" : "不支援！",
+    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
+    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
+    "Start a conversation" : "新對話",
+    "Share" : "分享",
+    "Password required" : "請輸入密碼",
+    "Cancel" : "取消",
+    "Submit" : "送出",
+    "Leave call" : "離開通話",
+    "Start call" : "通話",
+    "Change password" : "變更密碼",
+    "Set password" : "設定密碼",
+    "Rename" : "重新命名",
+    "Conversation with {name}" : "和 {name} 的談話",
+    "You" : "您",
+    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
+    "New message …" : "新訊息 ...",
+    "Send" : "傳送",
+    "Today" : "今天",
+    "Yesterday" : "昨天",
+    "File to share" : "要分享的檔案",
+    "Edit" : "編輯",
+    "Mute audio" : "靜音",
+    "Disable video" : "停用視訊",
+    "Share screen" : "分享螢幕",
+    "Mute audio (m)" : "靜音 (m)",
+    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
     "Always notify" : "總是通知",
-    "Never notify" : "取消提醒"
+    "Never notify" : "取消提醒",
+    "Close" : "關閉",
+    "Enter name for a new conversation" : "輸入新對話名稱",
+    "Room name can not be empty" : "名稱不能空白"
 },
 "nplurals=1; plural=0;");
