@@ -78,6 +78,9 @@ class Capabilities implements IPublicCapability {
 					'invite-groups-and-mails',
 					'locked-one-to-one-rooms',
 					'read-only-rooms',
+					'chat-read-marker',
+					'webinary-lobby',
+					'start-call-flag',
 				],
 				'config' => [
 					'chat' => [
