@@ -23,6 +23,7 @@ declare(strict_types=1);
 namespace OCA\Spreed\Chat\Command;
 
 
+use OCA\Spreed\Chat\ChatManager;
 use OCA\Spreed\Model\Command;
 use OCA\Spreed\Room;
 use OCA\Spreed\Service\CommandService;
@@ -76,7 +77,7 @@ class Executor {
 				'user' => $user,
 				'visibility' => $command->getResponse(),
 				'output' => $e->getMessage(),
-			]));
+			]), ChatManager::MAX_CHAT_LENGTH);
 			$message->setActor('bots', $command->getName());
 			$message->setVerb('command');
 			return;
@@ -95,7 +96,7 @@ class Executor {
 			'user' => $user,
 			'visibility' => $command->getResponse(),
 			'output' => $output,
-		]));
+		]), ChatManager::MAX_CHAT_LENGTH);
 		$message->setActor('bots', $command->getName());
 		$message->setVerb('command');
 	}
@@ -120,7 +121,16 @@ class Executor {
 
 			$response = trim($response);
 			if (strpos($response, "\n")) {
-				$helps[] = substr($response, 0, strpos($response, "\n"));
+				$tempHelp = substr($response, 0, strpos($response, "\n"));
+				if ($tempHelp === 'Description:') {
+					$hasHelpSection = strpos($response, "\nHelp:\n");
+					if ($hasHelpSection !== false) {
+						// Symfony console command with --help detected
+						$tempHelp = substr($response, $hasHelpSection + 7);
+						$tempHelp = substr($tempHelp, 0, strpos($tempHelp, "\n"));
+					}
+				}
+				$helps[] = $tempHelp;
 			} else {
 				$helps[] = $response;
 			}
@@ -139,7 +149,17 @@ class Executor {
 			$input = explode(' ', $arguments, 2);
 			if (count($input) === 1) {
 				$command = $this->commandService->find('', $arguments);
-				return $this->execShell($room, $message, $command, '--help');
+				$response = $this->execShell($room, $message, $command, '--help');
+
+				if (strpos($response, 'Description:') === 0) {
+					$hasHelpSection = strpos($response, "\nHelp:\n");
+					if ($hasHelpSection !== false) {
+						// Symfony console command with --help detected
+						$response = substr($response, $hasHelpSection + 7);
+					}
+				}
+
+				return $response;
 			}
 
 			[$app, $cmd] = $input;
@@ -178,7 +198,7 @@ class Executor {
 			);
 		} catch (\InvalidArgumentException $e) {
 			$this->logger->logException($e);
-			return '';
+			return $this->l->t('An error occurred while running the command. Please ask an administrator to check the logs.');
 		}
 	}
 }
