@@ -138,6 +138,18 @@ class SystemMessage {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You locked the conversation');
 			}
+		} else if ($message === 'lobby_timer_reached') {
+			$parsedMessage = $this->l->t('The conversation is now open to everyone');
+		} else if ($message === 'lobby_none') {
+			$parsedMessage = $this->l->t('{actor} opened the conversation to everyone');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You opened the conversation to everyone');
+			}
+		} else if ($message === 'lobby_non_moderators') {
+			$parsedMessage = $this->l->t('{actor} restricted the conversation to moderators');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You restricted the conversation to moderators');
+			}
 		} else if ($message === 'guests_allowed') {
 			$parsedMessage = $this->l->t('{actor} allowed guests');
 			if ($currentUserIsActor) {
@@ -235,8 +247,7 @@ class SystemMessage {
 			throw new \OutOfBoundsException('Unknown subject');
 		}
 
-		$comment->setMessage($message, ChatManager::MAX_CHAT_LENGTH);
-		$chatMessage->setMessage($parsedMessage, $parsedParameters);
+		$chatMessage->setMessage($parsedMessage, $parsedParameters, $message);
 	}
 
 	/**
@@ -330,7 +341,7 @@ class SystemMessage {
 
 		return [
 			'type' => 'guest',
-			'id' => $sessionHash,
+			'id' => 'guest/' . $sessionHash,
 			'name' => $this->guestNames[$sessionHash],
 		];
 	}
@@ -349,6 +360,13 @@ class SystemMessage {
 		$displayedUsers = $numUsers;
 
 		switch ($numUsers) {
+			case 0:
+				$subject = $this->l->n(
+					'Call with %n guest (Duration {duration})',
+					'Call with %n guests (Duration {duration})',
+					$parameters['guests']
+				);
+				break;
 			case 1:
 				$subject = $this->l->t('Call with {user1} and {user2} (Duration {duration})');
 				$subject = str_replace('{user2}', $this->l->n('%n guest', '%n guests', $parameters['guests']), $subject);
@@ -390,8 +408,10 @@ class SystemMessage {
 		}
 
 		$params = [];
-		for ($i = 1; $i <= $displayedUsers; $i++) {
-			$params['user' . $i] = $this->getUser($parameters['users'][$i - 1]);
+		if ($displayedUsers > 0) {
+			for ($i = 1; $i <= $displayedUsers; $i++) {
+				$params['user' . $i] = $this->getUser($parameters['users'][$i - 1]);
+			}
 		}
 
 		$subject = str_replace('{duration}', $this->getDuration($parameters['duration']), $subject);
