@@ -28,6 +28,7 @@ use OCA\Spreed\Chat\AutoComplete\Sorter;
 use OCA\Spreed\Chat\ChatManager;
 use OCA\Spreed\Chat\MessageParser;
 use OCA\Spreed\GuestManager;
+use OCA\Spreed\Model\Message;
 use OCA\Spreed\Room;
 use OCA\Spreed\TalkSession;
 use OCP\AppFramework\Http;
@@ -37,6 +38,7 @@ use OCP\Collaboration\AutoComplete\IManager;
 use OCP\Collaboration\Collaborators\ISearchResult;
 use OCP\Comments\IComment;
 use OCP\Comments\MessageTooLongException;
+use OCP\Comments\NotFoundException;
 use OCP\IL10N;
 use OCP\IRequest;
 use OCP\IUserManager;
@@ -110,6 +112,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @PublicPage
 	 * @RequireParticipant
 	 * @RequireReadWriteConversation
+	 * @RequireModeratorOrNoLobby
 	 *
 	 * Sends a new chat message to the given room.
 	 *
@@ -118,11 +121,12 @@ class ChatController extends AEnvironmentAwareController {
 	 *
 	 * @param string $message the message to send
 	 * @param string $actorDisplayName for guests
+	 * @param int $replyTo Parent id which this message is a reply to
 	 * @return DataResponse the status code is "201 Created" if successful, and
 	 *         "404 Not found" if the room or session for a guest user was not
 	 *         found".
 	 */
-	public function sendMessage(string $message, string $actorDisplayName = ''): DataResponse {
+	public function sendMessage(string $message, string $actorDisplayName = '', int $replyTo = 0): DataResponse {
 
 		if ($this->userId === null) {
 			$actorType = 'guests';
@@ -146,11 +150,27 @@ class ChatController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
+		$parent = $parentMessage = null;
+		if ($replyTo !== 0) {
+			try {
+				$parent = $this->chatManager->getParentComment($this->room, (string) $replyTo);
+			} catch (NotFoundException $e) {
+				// Someone is trying to reply cross-rooms or to a non-existing message
+				return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			}
+
+			$parentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parent, $this->l);
+			$this->messageParser->parseMessage($parentMessage);
+			if ($parentMessage->getMessageType() === 'system' || $parentMessage->getMessageType() === 'command') {
+				return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			}
+		}
+
 		$this->room->ensureOneToOneRoomIsFilled();
 		$creationDateTime = $this->timeFactory->getDateTime('now', new \DateTimeZone('UTC'));
 
 		try {
-			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime);
+			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, $parent);
 		} catch (MessageTooLongException $e) {
 			return new DataResponse([], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (\Exception $e) {
@@ -164,22 +184,17 @@ class ChatController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_CREATED);
 		}
 
-		return new DataResponse([
-			'id' => (int) $comment->getId(),
-			'token' => $this->room->getToken(),
-			'actorType' => $chatMessage->getActorType(),
-			'actorId' => $chatMessage->getActorId(),
-			'actorDisplayName' => $chatMessage->getActorDisplayName(),
-			'timestamp' => $comment->getCreationDateTime()->getTimestamp(),
-			'message' => $chatMessage->getMessage(),
-			'messageParameters' => $chatMessage->getMessageParameters(),
-			'systemMessage' => $chatMessage->getMessageType() === 'system' ? $comment->getMessage() : '',
-		], Http::STATUS_CREATED);
+		$data = $this->messageToData($chatMessage);
+		if ($parentMessage instanceof Message) {
+			$data['parent'] = $this->messageToData($parentMessage);
+		}
+		return new DataResponse($data, Http::STATUS_CREATED);
 	}
 
 	/**
 	 * @PublicPage
 	 * @RequireParticipant
+	 * @RequireModeratorOrNoLobby
 	 *
 	 * Receives chat messages from the given room.
 	 *
@@ -213,6 +228,9 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $limit Number of chat messages to receive (100 by default, 200 at most)
 	 * @param int $lastKnownMessageId The last known message (serves as offset)
 	 * @param int $timeout Number of seconds to wait for new messages (30 by default, 30 at most)
+	 * @param int $setReadMarker Automatically set the last read marker when 1,
+	 *                           if your client does this itself via chat/{token}/read set to 0
+	 * @param int $includeLastKnown Include the $lastKnownMessageId in the messages when 1 (default 0)
 	 * @return DataResponse an array of chat messages, "404 Not found" if the
 	 *         room token was not valid or "304 Not modified" if there were no messages;
 	 *         each chat message is an array with
@@ -220,7 +238,7 @@ class ChatController extends AEnvironmentAwareController {
 	 *         'actorDisplayName', 'timestamp' (in seconds and UTC timezone) and
 	 *         'message'.
 	 */
-	public function receiveMessages(int $lookIntoFuture, int $limit = 100, int $lastKnownMessageId = 0, int $timeout = 30): DataResponse {
+	public function receiveMessages(int $lookIntoFuture, int $limit = 100, int $lastKnownMessageId = 0, int $timeout = 30, int $setReadMarker = 1, int $includeLastKnown = 0): DataResponse {
 		$limit = min(200, $limit);
 		$timeout = min(30, $timeout);
 
@@ -228,54 +246,157 @@ class ChatController extends AEnvironmentAwareController {
 			$this->room->ping($this->participant->getUser(), $this->participant->getSessionId(), $this->timeFactory->getTime());
 		}
 
+		/**
+		 * Automatic last read message marking for old clients
+		 * This is pretty dumb and does not give the best and native feeling
+		 * you are used to from other chat apps. The clients should manually
+		 * set the read marker depending on the view port of the set of messages.
+		 *
+		 * We are only setting it automatically here for old clients and the
+		 * web UI, until it can be fixed in Vue. To not use too much broken data,
+		 * we only update the read marker to the last known id, when it is higher
+		 * then the current read marker.
+		 */
+		if ($lookIntoFuture && $setReadMarker === 1 &&
+			$lastKnownMessageId > $this->participant->getLastReadMessage()) {
+			$this->participant->setLastReadMessage($lastKnownMessageId);
+		}
+
 		$currentUser = $this->userManager->get($this->userId);
 		if ($lookIntoFuture) {
-			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser);
+			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser, (bool) $includeLastKnown);
 		} else {
-			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit);
+			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit, (bool) $includeLastKnown);
 		}
 
 		if (empty($comments)) {
 			return new DataResponse([], Http::STATUS_NOT_MODIFIED);
 		}
 
-		$messages = [];
+		$i = 0;
+		$messages = $commentIdToIndex = $parentIds = [];
 		foreach ($comments as $comment) {
+			$id = (int) $comment->getId();
 			$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
 			$this->messageParser->parseMessage($message);
 
 			if (!$message->getVisibility()) {
+				$commentIdToIndex[$id] = null;
 				continue;
 			}
 
-			$messages[] = [
-				'id' => (int) $comment->getId(),
-				'token' => $this->room->getToken(),
-				'actorType' => $message->getActorType(),
-				'actorId' => $message->getActorId(),
-				'actorDisplayName' => $message->getActorDisplayName(),
-				'timestamp' => $comment->getCreationDateTime()->getTimestamp(),
-				'message' => $message->getMessage(),
-				'messageParameters' => $message->getMessageParameters(),
-				'systemMessage' => $message->getMessageType() === 'system' ? $comment->getMessage() : '',
-			];
+			if ($comment->getParentId() !== '0') {
+				$parentIds[$id] = $comment->getParentId();
+			}
+
+			$messages[] = $this->messageToData($message);
+			$commentIdToIndex[$id] = $i;
+			$i++;
 		}
 
+		/**
+		 * Set the parent for reply-messages
+		 */
+		$loadedParents = [];
+		foreach ($parentIds as $commentId => $parentId) {
+			$commentKey = $commentIdToIndex[$commentId];
+
+			// Parent is already parsed in the message list
+			if (!empty($commentIdToIndex[$parentId])) {
+				$parentKey = $commentIdToIndex[$parentId];
+				$messages[$commentKey]['parent'] = $messages[$parentKey];
+
+				// We don't show nested parents…
+				unset($messages[$commentKey]['parent']['parent']);
+				continue;
+			}
+
+			// Parent was already loaded manually for another comment
+			if (!empty($loadedParents[$parentId])) {
+				$messages[$commentKey]['parent'] = $loadedParents[$parentId];
+				continue;
+			}
+
+			// Parent was not skipped due to visibility, so we need to manually grab it.
+			if (!isset($commentIdToIndex[$parentId])) {
+				try {
+					$comment = $this->chatManager->getParentComment($this->room, $parentId);
+					$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
+					$this->messageParser->parseMessage($message);
+
+					if ($message->getVisibility()) {
+						$loadedParents[$parentId] = $this->messageToData($message);
+						$messages[$commentKey]['parent'] = $loadedParents[$parentId];
+					} else {
+						$loadedParents[$parentId] = [
+							'id' => $parentId,
+							'deleted' => true,
+						];
+					}
+				} catch (NotFoundException $e) {
+				}
+			}
+
+			// Message is not visible to the user
+			$messages[$commentKey]['parent'] = [
+				'id' => $parentId,
+				'deleted' => true,
+			];
+		}
 
 		$response = new DataResponse($messages, Http::STATUS_OK);
 
 		$newLastKnown = end($comments);
 		if ($newLastKnown instanceof IComment) {
 			$response->addHeader('X-Chat-Last-Given', $newLastKnown->getId());
+			/**
+			 * This false set the read marker on new messages although you
+			 * navigated away to a different chat already. So we removed this
+			 * and instead update the read marker before your next waiting.
+			 * So when you are still there, it will just have a wrong read
+			 * marker for the time until your next request starts, while it will
+			 * not update the value, when you actually left the chat already.
+			if ($setReadMarker === 1 && $lookIntoFuture) {
+				$this->participant->setLastReadMessage((int) $newLastKnown->getId());
+			}
+			*/
 		}
 
 		return $response;
 	}
 
+	protected function messageToData(Message $message): array {
+		return [
+			'id' => (int) $message->getComment()->getId(),
+			'token' => $message->getRoom()->getToken(),
+			'actorType' => $message->getActorType(),
+			'actorId' => $message->getActorId(),
+			'actorDisplayName' => $message->getActorDisplayName(),
+			'timestamp' => $message->getComment()->getCreationDateTime()->getTimestamp(),
+			'message' => $message->getMessage(),
+			'messageParameters' => $message->getMessageParameters(),
+			'systemMessage' => $message->getMessageType() === 'system' ? $message->getMessageRaw() : '',
+			'messageType' => $message->getMessageType(),
+		];
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @RequireParticipant
+	 *
+	 * @param int $lastReadMessage
+	 * @return DataResponse
+	 */
+	public function setReadMarker(int $lastReadMessage): DataResponse {
+		$this->participant->setLastReadMessage($lastReadMessage);
+		return new DataResponse();
+	}
+
 	/**
 	 * @PublicPage
 	 * @RequireParticipant
 	 * @RequireReadWriteConversation
+	 * @RequireModeratorOrNoLobby
 	 *
 	 * @param string $search
 	 * @param int $limit
@@ -298,14 +419,16 @@ class ChatController extends AEnvironmentAwareController {
 		$this->autoCompleteManager->runSorters(['talk_chat_participants'], $results, [
 			'itemType' => 'chat',
 			'itemId' => (string) $this->room->getId(),
+			'search' => $search,
 		]);
 
 		$results = $this->prepareResultArray($results);
 
-		if (($search === '' || strpos('all', $search) !== false) && $this->room->getType() !== Room::ONE_TO_ONE_CALL) {
+		$roomDisplayName = $this->room->getDisplayName($this->participant->getUser());
+		if (($search === '' || strpos('all', $search) !== false || stripos($roomDisplayName, $search) !== false) && $this->room->getType() !== Room::ONE_TO_ONE_CALL) {
 			array_unshift($results, [
 				'id' => 'all',
-				'label' => $this->room->getDisplayName($this->participant->getUser()),
+				'label' => $roomDisplayName,
 				'source' => 'calls',
 			]);
 		}
