@@ -28,6 +28,8 @@ use OCA\Spreed\Chat\CommentsManager;
 use OCA\Spreed\Exceptions\ParticipantNotFoundException;
 use OCA\Spreed\Exceptions\RoomNotFoundException;
 use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\Comments\IComment;
+use OCP\Comments\NotFoundException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IConfig;
 use OCP\IDBConnection;
@@ -152,6 +154,7 @@ class Manager {
 			(int) $row['active_guests'],
 			$activeSince,
 			$lastActivity,
+			(int) $row['last_message'],
 			$lastMessage,
 			$lobbyTimer,
 			(string) $row['object_type'],
@@ -187,6 +190,14 @@ class Manager {
 		);
 	}
 
+	public function loadLastCommentInfo(int $id): ?IComment {
+		try {
+			return $this->commentsManager->get((string)$id);
+		} catch (NotFoundException $e) {
+			return null;
+		}
+	}
+
 	/**
 	 * @param string $participant
 	 * @param bool $includeLastMessage
